@@ -10,7 +10,6 @@
 #include <libgnomeui/gnome-window-icon.h>
 
 #include "gnome-calc.h"
-#include "sr.h"
 
 /* values for selection info */
 enum {
@@ -27,6 +26,10 @@ static void
 about_cb (GtkWidget *widget, gpointer data)
 {
 	static GtkWidget *about = NULL;
+	GdkPixbuf  	 *pixbuf;
+	GError     	 *error = NULL;
+	gchar      	 *file;
+	
 	gchar *authors[] = {
 		"George Lebl <jirka@5z.com>",
 		"Bastien Nocera <hadess@hadess.net> (fixes)",
@@ -44,14 +47,28 @@ about_cb (GtkWidget *widget, gpointer data)
 		gdk_window_raise(about->window);
 		return;
 	}
-	about = gnome_about_new(_("The GNOME Calculator"), VERSION,
+	
+	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-calc2.png", FALSE, NULL);
+	pixbuf = gdk_pixbuf_new_from_file (file, &error);
+	
+	if (error) {
+		g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
+		g_error_free (error);
+	}
+	g_free (file);
+	
+	about = gnome_about_new(_("GNOME Calculator"), VERSION,
 				"(C) 1998 the Free Software Foundation",
 				_("Simple double precision calculator similiar "
 				  "to xcalc"),
 				(const char **)authors,
 				(const char **)documenters,
 				strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-				NULL);
+				pixbuf);
+	if (pixbuf) {
+		gdk_pixbuf_unref (pixbuf);
+	}			
+				
 	gtk_signal_connect(GTK_OBJECT(about), "destroy",
 			   GTK_SIGNAL_FUNC(gtk_widget_destroyed), &about);
 	gtk_widget_show (about);
@@ -70,7 +87,7 @@ copy_contents (GtkWidget *widget, gpointer data)
 	strcpy(copied_string, gnome_calc_get_result_string(GNOME_CALC (calc)));
 	g_strstrip(copied_string);
 	gtk_selection_owner_set (app,
-				 GDK_SELECTION_PRIMARY,
+				 GDK_SELECTION_CLIPBOARD,
 				 GDK_CURRENT_TIME);
 }
 
@@ -102,7 +119,7 @@ selection_handle (GtkWidget *widget,
 }
 
 /* Menus */
-static GnomeUIInfo file_menu[] = {
+static GnomeUIInfo calculator_menu[] = {
 	GNOMEUIINFO_MENU_EXIT_ITEM(quit_cb,NULL),
 	GNOMEUIINFO_END
 };
@@ -113,31 +130,47 @@ static GnomeUIInfo edit_menu[] = {
 };
 
 static GnomeUIInfo help_menu[] = {
-	GNOMEUIINFO_HELP("gcalc"),
+	GNOMEUIINFO_HELP("gnome-calculator"),
 	GNOMEUIINFO_MENU_ABOUT_ITEM(about_cb,NULL),
 	GNOMEUIINFO_END
 };
 
 static GnomeUIInfo gcalc_menu[] = {
-	GNOMEUIINFO_MENU_FILE_TREE(file_menu),
+    { GNOME_APP_UI_SUBTREE_STOCK, N_("_Calculator"), NULL,
+      calculator_menu, NULL, NULL, (GnomeUIPixmapType) 0,
+      NULL, 0, (GdkModifierType) 0, NULL },
 	GNOMEUIINFO_MENU_EDIT_TREE(edit_menu),
 	GNOMEUIINFO_MENU_HELP_TREE(help_menu),
         GNOMEUIINFO_END
 };
 
-static gboolean analog = FALSE;
+static int save_session(GnomeClient        *client,
+                        gint                phase,
+                        GnomeRestartStyle   save_style,
+                        gint                shutdown,
+                        GnomeInteractStyle  interact_style,
+                        gint                fast,
+                        gpointer            client_data) {
+       gchar *argv[]= { NULL };
+
+       argv[0] = (char*) client_data;
+       gnome_client_set_clone_command(client, 1, argv);
+       gnome_client_set_restart_command(client, 1, argv);
+
+       return TRUE;
+}
+
+static gint client_die(GnomeClient *client, gpointer client_data)
+{
+       gtk_main_quit ();
+}
 
-struct poptOption options [] = {
-  { "analog", '\0', POPT_ARG_NONE|POPT_ARGFLAG_ONEDASH, &analog, 0,
-    N_("Run in analog (slide rule) mode"), NULL },
-  POPT_AUTOHELP
-  { NULL, 0, 0, NULL, 0}
-};
 
 
 int
 main(int argc, char *argv[])
 {
+	GnomeClient *client;
 	static GtkTargetEntry targets[] = {
 		{ "STRING", TARGET_STRING },
 		{ "TEXT",   TARGET_TEXT }, 
@@ -150,18 +183,13 @@ main(int argc, char *argv[])
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 	textdomain(GETTEXT_PACKAGE);
 
-	gnome_program_init ("gcalc", VERSION, LIBGNOMEUI_MODULE,
-			argc, argv, GNOME_PARAM_POPT_TABLE, options, NULL);
+	gnome_program_init ("gnome-calculator", VERSION, LIBGNOMEUI_MODULE,
+			argc, argv, GNOME_PARAM_APP_DATADIR,DATADIR, NULL);
 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-calc2.png");
 
-	if (analog) {
-		run_slide_rule ();
-		return 0;
-	}
-
-        app = gnome_app_new("gcalc", _("GNOME Calculator"));
-	gtk_window_set_wmclass (GTK_WINDOW (app), "gcalc", "gcalc");
-	gtk_window_set_policy (GTK_WINDOW (app), FALSE, TRUE, FALSE);
+        app = gnome_app_new("gnome-calculator", _("GNOME Calculator"));
+	gtk_window_set_wmclass (GTK_WINDOW (app), "gnome-calculator", "gnome-calculator");
+	gtk_window_set_resizable (GTK_WINDOW (app), TRUE);
 
         gtk_signal_connect(GTK_OBJECT(app), "delete_event",
 			GTK_SIGNAL_FUNC(quit_cb), NULL);
@@ -173,12 +201,18 @@ main(int argc, char *argv[])
 	gnome_calc_bind_extra_keys (GNOME_CALC (calc), GTK_WIDGET (app));
 	gtk_widget_show(calc);
 
-	gtk_selection_add_targets (GTK_WIDGET (app), GDK_SELECTION_PRIMARY,
+	gtk_selection_add_targets (GTK_WIDGET (app), GDK_SELECTION_CLIPBOARD,
 				   targets, n_targets);
 
         gtk_signal_connect(GTK_OBJECT(app), "selection_get",
 			   GTK_SIGNAL_FUNC(selection_handle), NULL);
 
+	client = gnome_master_client();
+	g_signal_connect (client, "save_yourself",
+				G_CALLBACK(save_session), (gpointer)argv[0]);
+	g_signal_connect (client, "die",
+				G_CALLBACK(client_die), NULL);
+
 	gnome_app_set_contents(GNOME_APP(app), calc);
 
 	/* add calculator accel table to our window*/
@@ -191,3 +225,4 @@ main(int argc, char *argv[])
 
 	return 0;
 }
+
