@@ -1,4 +1,4 @@
-/* $Id: gdict-about.c,v 1.8 2002/02/28 23:01:54 kevinv Exp $ */
+/* $Id: gdict-about.c,v 1.9 2002/04/29 01:06:10 gman Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -26,6 +26,10 @@
 
 static GtkWidget *gdict_about_new (void)
 {
+    GdkPixbuf   *pixbuf;
+    GError  	*error = NULL;
+    gchar 	*file;
+    
     const gchar *authors[] = {
         "Mike Hughes <mfh@psilord.com>",
         "Spiros Papadimitriou <spapadim+@cs.cmu.edu>",
@@ -39,6 +43,16 @@ static GtkWidget *gdict_about_new (void)
     gchar *translator_credits = _("translator_credits");
     GtkWidget *about;
     
+    file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gdict.png", FALSE, NULL);
+    pixbuf = gdk_pixbuf_new_from_file (file, &error);
+    
+    if (error) {
+    	   g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
+	   g_error_free (error);	
+    }
+    
+    g_free (file);    
+    
     about = gnome_about_new ("GNOME Dictionary", VERSION,
                              "Copyright 1999 by Mike Hughes",
                              _("Client for MIT dictionary server.\n"
@@ -47,7 +61,14 @@ static GtkWidget *gdict_about_new (void)
 			     (const char **)authors,
 			     (const char **)documenters,
 			     strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-                             NULL);
+                             pixbuf);
+    if (pixbuf) {
+    	   gdk_pixbuf_unref (pixbuf);
+    }
+
+    gtk_window_set_wmclass (GTK_WINDOW (about), "gdict", "GNOME Dictionary");
+    gnome_window_icon_set_from_file (GTK_WINDOW (about), GNOME_ICONDIR"/gdict.png");				     
+			     
     return about;
 }
 
