@@ -323,15 +323,15 @@ InitApp ()
   user_prefs = &user_prefs_struct;
   SetDefaultUserPrefs(user_prefs);
 
+  /*  Display main window */
+  CreateMainWin ();
+
   /* Read databases */
   open_databases ();
 
   /*  Read files and init data. */
   if (InitPages () < 0)
     ShowErrMessage (_("No log files to open"));
-
-  /*  Display main window */
-  CreateMainWin ();
 }
 
 /* ----------------------------------------------------------------------
@@ -361,8 +361,6 @@ CreateMainWin ()
    gtk_widget_size_allocate ( GTK_WIDGET (app), &req_size );
    gtk_signal_connect (GTK_OBJECT (app), "destroy",
 		       GTK_SIGNAL_FUNC (destroy), NULL);
-   gtk_signal_connect (GTK_OBJECT (app), "delete_event",
-		       GTK_SIGNAL_FUNC (destroy), NULL);
 
    /* Create menus */
    gnome_app_create_menus (GNOME_APP (app), main_menu);
@@ -485,7 +483,7 @@ CreateMainWin ()
    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
    gtk_widget_show (vbox);
-   gtk_widget_show (app);
+   gtk_widget_show_now (app);
 
 }
 
@@ -845,8 +843,10 @@ CloseApp (void)
 
    numlogs = 0;
 
-   if (G_IS_OBJECT (log_layout))
+   if (G_IS_OBJECT (log_layout)) {
       g_object_unref (G_OBJECT (log_layout));
+      log_layout = NULL;
+   }
 
    gtk_main_quit ();   
 }
